@@ -56,6 +56,13 @@
  *			- Multiple picoblaze support
  *			- IO ports (and irq) can be changed from other software. 
  *          - Download mem file with JTAG
+ * V0.7:
+ *     ADDED
+ *          - internationalizion support (=i18n)
+ *          - #include <iee1284.h> removed, gave compile error on some systems.
+ *
+ *     BUG FIX
+ *			- Assembler: 'TEST' carry bit was not set properly because MSB bit was not evaluated.
  */
 
 
@@ -83,8 +90,10 @@
 #include <ksimpleconfig.h>
 #include <khelpmenu.h>
 #include <kaboutdata.h>
+#include <kcmdlineargs.h>
 
-const char version[] = "0.6" ;
+//const char version[] = "0.6" ;
+extern const char *version ;
 
 enum IDs {
 	START_SIM_ID = 0,
@@ -125,21 +134,21 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 	KToolBar *toolbar = new KToolBar( this ) ;
 	addDockWindow( toolbar ) ;
 	
-	toolbar->insertButton( "filenew", -1, SIGNAL( clicked() ), m_editor, SLOT( slotNewFile() ), true, "New" ) ;
-	toolbar->insertButton( "fileopen", -1, SIGNAL( clicked() ), m_editor, SLOT( slotOpen() ), true, "Open" ) ;
-	toolbar->insertButton( "filesave", -1, SIGNAL( clicked() ), m_editor, SLOT( slotSave() ), true, "Save" ) ;
-	toolbar->insertButton( "filesaveas", -1, SIGNAL( clicked() ), m_editor, SLOT( slotSaveAs() ), true, "Save As" ) ;
+	toolbar->insertButton( "filenew", -1, SIGNAL( clicked() ), m_editor, SLOT( slotNewFile() ), true, i18n("New") ) ;
+	toolbar->insertButton( "fileopen", -1, SIGNAL( clicked() ), m_editor, SLOT( slotOpen() ), true, i18n("Open") ) ;
+	toolbar->insertButton( "filesave", -1, SIGNAL( clicked() ), m_editor, SLOT( slotSave() ), true, i18n("Save") ) ;
+	toolbar->insertButton( "filesaveas", -1, SIGNAL( clicked() ), m_editor, SLOT( slotSaveAs() ), true, i18n("Save As") ) ;
 	
 	m_debugBar = new KToolBar( this ) ;
 	addDockWindow( m_debugBar ) ;
-	m_debugBar->insertButton( UserIcon( "rebuild" ), COMPILE_ID, SIGNAL( clicked() ), this, SLOT( compile() ), true, "Compile" ) ;
-	m_debugBar->insertButton( "run", START_SIM_ID, SIGNAL( clicked() ), this, SLOT( startSim() ), true, "Start/Stop Debug" ) ;
+	m_debugBar->insertButton( UserIcon( "rebuild" ), COMPILE_ID, SIGNAL( clicked() ), this, SLOT( compile() ), true, i18n ("Compile") ) ;
+	m_debugBar->insertButton( "run", START_SIM_ID, SIGNAL( clicked() ), this, SLOT( startSim() ), true, i18n("Start/Stop Debug") ) ;
 	m_debugBar->insertSeparator() ;
-	m_debugBar->insertButton( UserIcon( "continue" ), RUN_ID, SIGNAL( clicked() ), this, SLOT( startStop() ), false, "Continue" ) ;
+	m_debugBar->insertButton( UserIcon( "continue" ), RUN_ID, SIGNAL( clicked() ), this, SLOT( startStop() ), false, i18n ("Continue") ) ;
 	
-	m_debugBar->insertButton( UserIcon( "next" ), NEXT_ID, SIGNAL( clicked() ), m_simulator, SLOT( next() ), false, "Next" ) ;
+	m_debugBar->insertButton( UserIcon( "next" ), NEXT_ID, SIGNAL( clicked() ), m_simulator, SLOT( next() ), false, i18n ("Next") ) ;
 	m_debugBar->insertButton( UserIcon( "interrupt" ), INTERRUPT_ID, SIGNAL( clicked() ), m_simulator, SLOT( interrupt() ), false, "Interrupt" ) ; 
-	m_debugBar->insertButton( UserIcon( "reset" ), RESET_ID, SIGNAL( clicked() ), m_simulator, SLOT( reset() ), false, "Reset" ) ;
+	m_debugBar->insertButton( UserIcon( "reset" ), RESET_ID, SIGNAL( clicked() ), m_simulator, SLOT( reset() ), false, i18n ("Reset") ) ;
 	
 	connect( this, SIGNAL( run() ), m_simulator, SLOT( run() ) );
 	connect( this, SIGNAL( stop()  ), m_simulator, SLOT( stop()  ) ) ;
@@ -148,8 +157,8 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 	connect( m_processorView, SIGNAL( processorFlagsChanged() ), this, SLOT( updateProcessorFlags() ) ) ;
 	connect( m_messages, SIGNAL( clicked( QListViewItem * ) ), this, SLOT( messageListClicked( QListViewItem * ) ) ) ;
 	
-	m_messages->addColumn( "Line" ) ;
-	m_messages->addColumn( "Description" ) ;
+	m_messages->addColumn( i18n("Line") ) ;
+	m_messages->addColumn( i18n("Description") ) ;
 	m_messages->setSorting( -1, FALSE ) ;
 	m_simulator->setMessageList( m_messages ) ;
 
@@ -157,9 +166,9 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 	m_scratchpadView = NULL ;
 	m_serialView = NULL ;
 
-	statusBar()->insertItem( QString( "Mode: Edit" ), 0 ) ;
-	statusBar()->insertItem( QString( "Status: Stopped" ), 1 ) ;
-	statusBar()->insertItem( QString( "Instructions: 0" ), 2 ) ;
+	statusBar()->insertItem( QString( i18n("Mode: Edit") ), 0 ) ;
+	statusBar()->insertItem( QString( i18n("Status: Stopped") ), 1 ) ;
+	statusBar()->insertItem( QString( i18n("Instructions: 0") ), 2 ) ;
 
 	m_templateFile = "" ;
 	m_outputDir = "" ;
@@ -182,80 +191,64 @@ void KPicoSim::buildMenu()
 	exportMenu->insertItem( "HEX", this, SLOT( fileExportHEX() ) ) ;
 
 	m_fileMenu = new KPopupMenu( this ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filenew", KIcon::Small ), "New", this, SLOT( slotFileNew() ) ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileopen", KIcon::Small ), "Open", m_editor, SLOT( slotOpen() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "filenew", KIcon::Small ), i18n("New"), this, SLOT( slotFileNew() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "fileopen", KIcon::Small ), i18n("Open"), m_editor, SLOT( slotOpen() ) ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filesave", KIcon::Small ), "Save", m_editor, SLOT( slotSave() ), QKeySequence::QKeySequence( "CTRL+S" ) ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filesaveas", KIcon::Small ), "Save As...", m_editor, SLOT( slotSaveAs() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "filesave", KIcon::Small ), i18n("Save"), m_editor, SLOT( slotSave() ), QKeySequence::QKeySequence( "CTRL+S" ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "filesaveas", KIcon::Small ), i18n("Save As..."), m_editor, SLOT( slotSaveAs() ) ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileprint", KIcon::Small ), "Print...", m_editor, SLOT( slotPrint() ), QKeySequence::QKeySequence( "CTRL+P" ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "fileprint", KIcon::Small ), i18n("Print..."), m_editor, SLOT( slotPrint() ), QKeySequence::QKeySequence( "CTRL+P" ) ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( "Export", exportMenu ) ;
+	m_fileMenu->insertItem( i18n("Export"), exportMenu ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileclose", KIcon::Small ), "Quit", this, SLOT( slotClose() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "fileclose", KIcon::Small ), i18n("Quit"), this, SLOT( slotClose() ) ) ;
 	
 	m_editMenu = new KPopupMenu( this ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "undo", KIcon::Small ), "Undo", m_editor, SLOT( slotUndo() ),QKeySequence::QKeySequence( "CTRL+Z" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "redo", KIcon::Small ), "Redo", m_editor, SLOT( slotRedo() ),QKeySequence::QKeySequence( "CTRL+SHIFT+Z" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "undo", KIcon::Small ), i18n("Undo"), m_editor, SLOT( slotUndo() ),QKeySequence::QKeySequence( "CTRL+Z" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "redo", KIcon::Small ), i18n("Redo"), m_editor, SLOT( slotRedo() ),QKeySequence::QKeySequence( "CTRL+SHIFT+Z" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( "Select All", m_editor, SLOT( slotSelectAll() ),QKeySequence::QKeySequence( "CTRL+A" ) ) ;
+	m_editMenu->insertItem( i18n("Select All"), m_editor, SLOT( slotSelectAll() ),QKeySequence::QKeySequence( "CTRL+A" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( ldr->loadIcon( "editcut", KIcon::Small ), "Cut", m_editor, SLOT( slotCut() ),QKeySequence::QKeySequence( "CTRL+X" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "editcopy", KIcon::Small ), "Copy", m_editor, SLOT( slotCopy() ),QKeySequence::QKeySequence( "CTRL+C" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "editpaste", KIcon::Small ), "Paste", m_editor, SLOT( slotPaste() ),QKeySequence::QKeySequence( "CTRL+V" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "editcut", KIcon::Small ), i18n("Cut"), m_editor, SLOT( slotCut() ),QKeySequence::QKeySequence( "CTRL+X" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "editcopy", KIcon::Small ), i18n("Copy"), m_editor, SLOT( slotCopy() ),QKeySequence::QKeySequence( "CTRL+C" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "editpaste", KIcon::Small ), i18n( "Paste" ), m_editor, SLOT( slotPaste() ),QKeySequence::QKeySequence( "CTRL+V" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( ldr->loadIcon( "find", KIcon::Small ), "Find...", m_editor, SLOT( slotFind() ), QKeySequence::QKeySequence( "CTRL+F" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "find", KIcon::Small ), i18n("Find..."), m_editor, SLOT( slotFind() ), QKeySequence::QKeySequence( "CTRL+F" ) ) ;
 	m_editMenu->insertItem( "Find Next", m_editor, SLOT( slotFindNext() ), QKeySequence::QKeySequence( "F3" ) ) ;
 
 
 	m_debugMenu = new KPopupMenu( this ) ;
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( ldr->loadIcon( "rebuild", KIcon::Small ), "Compile", this, SLOT( compile() ), QKeySequence::QKeySequence( "SHIFT+F9" ) ) ;
-	m_debugMenu->insertItem( ldr->loadIcon( "run", KIcon::Small ), "Start Debug", this, SLOT( startSim() ), QKeySequence::QKeySequence( "F9" ) , START_SIM_ID ) ;
+	m_debugMenu->insertItem( ldr->loadIcon( "rebuild", KIcon::Small ), i18n("Compile"), this, SLOT( compile() ), QKeySequence::QKeySequence( "SHIFT+F9" ) ) ;
+	m_debugMenu->insertItem( ldr->loadIcon( "run", KIcon::Small ), i18n("Start Debug"), this, SLOT( startSim() ), QKeySequence::QKeySequence( "F9" ) , START_SIM_ID ) ;
 
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( "Continue", this, SLOT( startStop() ), QKeySequence::QKeySequence( "F10" ) , RUN_ID ) ;
-	m_debugMenu->insertItem( "Next", m_simulator, SLOT( next() ), QKeySequence::QKeySequence( "F5" ) , NEXT_ID ) ;
-	m_debugMenu->insertItem( "Interrupt", m_simulator, SLOT( interrupt() ), QKeySequence::QKeySequence( "F4" ) , INTERRUPT_ID ) ;
-	m_debugMenu->insertItem( "Reset", m_simulator, SLOT( reset() ), QKeySequence::QKeySequence( "F11" ) , RESET_ID ) ;
+	m_debugMenu->insertItem( i18n("Continue"), this, SLOT( startStop() ), QKeySequence::QKeySequence( "F10" ) , RUN_ID ) ;
+	m_debugMenu->insertItem( i18n("Next"), m_simulator, SLOT( next() ), QKeySequence::QKeySequence( "F5" ) , NEXT_ID ) ;
+	m_debugMenu->insertItem( i18n("Interrupt"), m_simulator, SLOT( interrupt() ), QKeySequence::QKeySequence( "F4" ) , INTERRUPT_ID ) ;
+	m_debugMenu->insertItem( i18n("Reset"), m_simulator, SLOT( reset() ), QKeySequence::QKeySequence( "F11" ) , RESET_ID ) ;
 	
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( "Toggle Breakpoint", m_editor, SLOT( slotToggleBreakpoint() ), QKeySequence::QKeySequence( "F8" ) ) ;
+	m_debugMenu->insertItem( i18n("Toggle Breakpoint"), m_editor, SLOT( slotToggleBreakpoint() ), QKeySequence::QKeySequence( "F8" ) ) ;
 	
 	m_settingsMenu = new KPopupMenu( this ) ;
-	m_settingsMenu->insertItem( "Configure Editor...", m_editor, SLOT( slotShowConfig() ) ) ;
+	m_settingsMenu->insertItem( i18n("Configure Editor..."), m_editor, SLOT( slotShowConfig() ) ) ;
 	
 	m_peripheralMenu = new KPopupMenu( this ) ;
-	m_peripheralMenu->insertItem( "I/O Port", this, SLOT( newIOPort() ) ) ;
-	m_peripheralMenu->insertItem( "Scratchpad", this, SLOT( showScratchpad() ), 0, VIEW_SCRATCHPAD_ID ) ;
-	m_peripheralMenu->insertItem( "Serial port", this, SLOT( showSerialPort() ), 0, VIEW_SERIAL_ID ) ;
+	m_peripheralMenu->insertItem( i18n("I/O Port"), this, SLOT( newIOPort() ) ) ;
+	m_peripheralMenu->insertItem( i18n("Scratchpad"), this, SLOT( showScratchpad() ), 0, VIEW_SCRATCHPAD_ID ) ;
+	m_peripheralMenu->insertItem( i18n("Serial port"), this, SLOT( showSerialPort() ), 0, VIEW_SERIAL_ID ) ;
 	
 	m_jtagMenu = new KPopupMenu( this ) ;
-	m_jtagMenu->insertItem( "Download", this, SLOT( jtagDownload() ) ) ;
+	m_jtagMenu->insertItem( i18n("Download"), this, SLOT( jtagDownload() ) ) ;
 
-	KAboutData *aboutData = new KAboutData( 
-		"kpicosim", 
-		"kpicosim", 
-		version, 
-		"IDE for the picoblaze\n\nCopyright (c) 2005 Mark Six", 
-		KAboutData::License_GPL,
-		0,
-		0,
-		"http://www.xs4all.nl/~marksix",
-		"m6@xs4all.nl"
-	 ) ;
-	aboutData->addAuthor( "Mark Six", "m6@xs4all.nl", "http://www.xs4all.nl/~marksix" ) ;
-
-	KHelpMenu *helpMenu = new KHelpMenu( this, aboutData, false  ) ;	
-	KPopupMenu *help = helpMenu->menu() ;
-
-	menuBar()->insertItem( "File", m_fileMenu ) ;
-	menuBar()->insertItem( "Edit", m_editMenu ) ;
-	menuBar()->insertItem( "Debug", m_debugMenu ) ;
-	menuBar()->insertItem( "Peripheral", m_peripheralMenu ) ;
-	menuBar()->insertItem( "JTAG", m_jtagMenu ) ;
-	menuBar()->insertItem( "Settings", m_settingsMenu ) ;
-	menuBar()->insertItem( "Help", help ) ;
+	menuBar()->insertItem( i18n("File"), m_fileMenu ) ;
+	menuBar()->insertItem( i18n("Edit"), m_editMenu ) ;
+	menuBar()->insertItem( i18n("Debug"), m_debugMenu ) ;
+	menuBar()->insertItem( i18n("Peripheral"), m_peripheralMenu ) ;
+	menuBar()->insertItem( i18n("JTAG"), m_jtagMenu ) ;
+	menuBar()->insertItem( i18n("Settings"), m_settingsMenu ) ;
+	menuBar()->insertItem( i18n("Help"), helpMenu() ) ;
 	
 	m_debugMenu->setItemEnabled( RUN_ID, false ) ;
 	m_debugMenu->setItemEnabled( NEXT_ID, false ) ;
@@ -284,7 +277,7 @@ void KPicoSim::jtagDownload()
 
 void KPicoSim::fileExportCOE()
 {
-	KMessageBox::information( this, "This function is not supported yet", "Export COE" ) ;
+	KMessageBox::information( this, i18n("This function is not supported yet"), i18n("Export COE") ) ;
 
 //	if ( compile() ) {
 		//m_simulator->exportCOE() ;
@@ -297,7 +290,8 @@ void KPicoSim::fileExportHEX()
 	QString filename = KFileDialog::getSaveFileName( QString::null, 
                                                      "*.hex|HEX files\n*|All files", 
 		   										     this,
-  												     "Export HEX" ) ;
+  												     i18n( "Export HEX" ) ) ;
+
 	if ( filename != "" && compile() ) {
 		m_simulator->exportHEX( filename, FALSE ) ;
 	}
@@ -309,7 +303,7 @@ void KPicoSim::fileExportMEM()
 	QString filename = KFileDialog::getSaveFileName( QString::null, 
                                                      "*.mem|MEM files\n*|All files", 
 		   										     this,
-  												     "Export MEM" ) ;
+  												     i18n( "Export MEM" ) ) ;
 	if ( filename != "" && compile() ) {
 		m_simulator->exportHEX( filename, TRUE ) ;
 	}
@@ -332,11 +326,11 @@ void KPicoSim::fileExportVHDL()
 	m_entityName = dlg.getEntityName() ;
 		
 	if ( compile() && m_simulator->exportVHDL( m_templateFile, m_outputDir, m_entityName ) ) {
-		appendMessage( "File '" + m_outputDir + "/" + m_entityName + ".vhd' exported" ) ;
-		appendMessage( "Template file '" + m_templateFile + "' used" ) ;
-		appendMessage( "***Export Success***" ) ;
+		appendMessage( QString( i18n("File '%1/%2.vhd' exported") ).arg( m_outputDir ).arg(m_entityName) ) ;
+		appendMessage( QString( i18n("Template file '%1' used").arg( m_templateFile ) ) ) ;
+		appendMessage( i18n("***Export Success***") ) ;
 	} else {
-		appendMessage( "***Export failed***" ) ;
+		appendMessage( i18n("***Export failed***") ) ;
 	}
 }
 
@@ -374,7 +368,7 @@ void KPicoSim::showSerialPort()
 {
 	if ( m_serialView == NULL ) {
 		m_serialView = new KSerialView( m_simulator->getCpu(), m_tabWidget ) ;
-		m_tabWidget->addTab( m_serialView, "Serial" ) ;
+		m_tabWidget->addTab( m_serialView, i18n( "Serial" ) ) ;
 		m_peripheralMenu->setItemChecked( VIEW_SERIAL_ID, true ) ;
 	} else {
 		m_peripheralMenu->setItemChecked( VIEW_SERIAL_ID, false ) ;
@@ -421,19 +415,19 @@ void KPicoSim::startStop()
 	if ( m_simulationMode ) {
 		
 		if ( !m_simulator->isRunning() ) {
-			m_debugMenu->changeItem( RUN_ID, "Stop" ) ;
+			m_debugMenu->changeItem( RUN_ID, i18n("Stop") ) ;
 			m_editor->clearExecutionMarker() ;
 			m_simulator->run() ;
-			statusBar()->changeItem( QString( "Status: Running" ), 1 ) ;
+			statusBar()->changeItem( QString( i18n("Status: Running" ) ), 1 ) ;
 			m_debugBar->setButton( RUN_ID, true ) ;
 		} else {
 			m_simulator->stop() ;
 			updateViews() ;
-			m_debugMenu->changeItem( RUN_ID, "Continue" ) ;
+			m_debugMenu->changeItem( RUN_ID, i18n("Continue") ) ;
 			m_editor->setExecutionMarker( m_simulator->getNextSourceLine() ) ;
-			statusBar()->changeItem( QString( "Status: Stopped" ), 1 ) ;
+			statusBar()->changeItem( QString( i18n("Status: Stopped") ), 1 ) ;
 			QString str ;
-			str.sprintf( "Instructions: %u", m_nrInstructions ) ;
+			str = QString( i18n("Instructions: %1") ).arg( m_nrInstructions) ;
 			statusBar()->changeItem( str, 2 ) ;
 			m_debugBar->setButton( RUN_ID, false ) ;
 		}
@@ -473,7 +467,7 @@ void KPicoSim::updateViews()
 	updateScratchpadView() ;
 
 	QString str ;
-	str.sprintf( "Instructions: %u", m_nrInstructions ) ;
+	str = QString( i18n("Instructions: %1") ).arg(m_nrInstructions) ;
 	statusBar()->changeItem( str, 2 ) ;
 }
 
@@ -518,31 +512,30 @@ bool KPicoSim::compile()
 	if ( !m_editor->save() ) 
 		return FALSE;
 
-	appendMessage( "File '" + m_editor->getFilename() + "' saved" ) ;
+	appendMessage( QString( i18n("File '%1' saved") ).arg( m_editor->getFilename() ) ) ;
 	m_simulator->setFilename( m_editor->getFilename() ) ;
 		
 	if ( m_simulator->compile() == TRUE ) {
-		appendMessage( "***Compile Success*** " ) ;
+		appendMessage( i18n("***Compile Success*** ") ) ;
 		return TRUE ;
 	} else {
-		appendMessage( "***Compile Failed*** " ) ;
+		appendMessage( i18n("***Compile Failed*** ") ) ;
 		return FALSE ;
 	}
 }
-
-
 void KPicoSim::startSim()
 {
 	KIconLoader * ldr = KGlobal::iconLoader() ;
 
 	if ( !m_simulationMode ) {
 		if ( compile() ) {
-			setCaption( m_editor->getFilename() + " [Debugging]" ) ;
-			m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "stop", KIcon::Small ), "Stop Debug" ) ;
+			setCaption( m_editor->getFilename() + i18n(" [Debugging]") ) ;
+			m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "stop", KIcon::Small ), i18n("Stop Debug") ) ;
 			m_debugBar->setButton( START_SIM_ID, true ) ;
 
+			m_nrInstructions = -1 ;
 			m_simulator->reset() ;
-			m_nrInstructions = 0 ;
+			
 			m_simulationMode = TRUE ;
 		}
 	} else {
@@ -550,16 +543,16 @@ void KPicoSim::startSim()
 			startStop() ;
 			
 		setCaption( m_editor->getFilename() ) ;
-		m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "run", KIcon::Small ), "Start Debug" ) ;
+		m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "run", KIcon::Small ), i18n("Start Debug") ) ;
 		m_debugBar->setButton( START_SIM_ID, false ) ;
 		m_editor->clearExecutionMarker() ;
 		m_simulationMode = FALSE ;
 	}
 	
 	if ( m_simulationMode ) {
-		statusBar()->changeItem( QString( "Mode: Debug" ), 0 ) ;
+		statusBar()->changeItem( i18n("Mode: Debug"), 0 ) ;
 	} else {
-		statusBar()->changeItem( QString( "Mode: Edit" ), 0 ) ;
+		statusBar()->changeItem( i18n("Mode: Edit"), 0 ) ;
 	}
 	
 	m_debugMenu->setItemEnabled( RUN_ID, m_simulationMode ) ;
@@ -582,14 +575,14 @@ void KPicoSim::removeIOPort( KPortView* ioport )
 void KPicoSim::closeGUI()
 {
 	KSimpleConfig config( "kpicosim" ) ;
-
 	config.setGroup( "Peripherals" ) ;
 	
 	config.writeEntry( "serial", m_serialView != NULL ) ;
 	config.writeEntry( "scratchpad", m_scratchpadView != NULL ) ; 
 	config.writeEntry( "filename", m_editor->getFilename() ) ;
 	config.writeEntry( "bitfile", m_bitfile ) ;
-
+	
+	saveWindowSize( &config ) ;
 /*
 	config.writeEntry( "numIOPorts", m_ioList.count() ) ;
 	for ( int i = 0 ; i < m_ioList.count() ; i++ ) {
@@ -613,6 +606,9 @@ void KPicoSim::openGUI()
 	m_editor->open( config.readEntry( "filename" ) ) ;
 	m_bitfile = config.readEntry( "bitfile" ) ;
 
+	restoreWindowSize( &config ) ;
+	
+
 /*
 	int nports = config.readPropertyEntry( "numIOPorts", QVariant::Int ).toInt() ;
 
